
/* Desktop Icons GNOME Shell extension
 *
 * Copyright (C) 2019 Sergio Costas (rastersoft@gmail.com)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

const Gtk = imports.gi.Gtk;
const GLib = imports.gi.GLib;
const Gio = imports.gi.Gio;
const Pango = imports.gi.Pango;
const ExtensionUtils = imports.misc.extensionUtils;
const Gettext = imports.gettext;


var _ = Gettext.domain('ding').gettext;

function init() {}

function buildPrefsWidget() {
    let extension = ExtensionUtils.getCurrentExtension();

    let localedir = extension.dir.get_child('locale');
    if (localedir.query_exists(null))
        Gettext.bindtextdomain('ding', localedir.get_path());

    const remoteDingActions = Gio.DBusActionGroup.get(
        Gio.DBus.session,
        'com.rastersoft.ding',
        '/com/rastersoft/ding/actions'
    );

    const box = new Gtk.Box({
        spacing: 6,
        orientation: Gtk.Orientation.VERTICAL,
    });

    const button = new Gtk.Button({
        label: _('Open DING settings'),
    });

    button.connect('clicked', () => {
        const timestamp = Gtk.get_current_event_time ?
            Gtk.get_current_event_time() : 0;
        remoteDingActions.activate_action('openPreferences',
            new GLib.Variant('u', timestamp));
    });

    const label = new Gtk.Label({
        label: '<i>' + _("To configure Desktop Icons NG, right-click in the desktop and choose the item: 'Desktop Icons Settings'") + '</i>',
        lines: 5,
        justify: Gtk.Justification.CENTER,
        wrap: true,
        use_markup: true,
        wrap_mode: Pango.WrapMode.WORD
    });

    if (box.add) {
        box.add(button);
        box.add(label);
    } else {
        box.append(button);
        box.append(label);
    }

    if (box.show_all) {
        box.show_all();
    }
    return box;
}
